==> houseteli_administrator-0.1.15-py3-none-any.whl: houseteli_administrator/h_auth/serializers.py <==
from dj_rest_auth.registration.serializers import RegisterSerializer
from rest_framework import serializers
from django.contrib.auth import get_user_model

User = get_user_model()

class CustomRegisterSerializer(RegisterSerializer):
    username = None
    email = serializers.EmailField(required=True)
    def custom_signup(self, request, user):
        user.email = self.data.get('email')
        user.save()


from rest_framework_simplejwt.serializers import TokenObtainPairSerializer
# from django.conf import settings
# from decouple import config
# account_type = config('ACCOUNTTYPE', default=None)
class CustomTokenObtainPairSerializer(TokenObtainPairSerializer):
    """
    Custom serializer to add extra claims to the JWT.
    """
    @classmethod
    def get_token(cls, user):
        token = super().get_token(user)
        
        # Add custom claims
        token['email'] = user.email
        token['first_name'] = user.first_name
        token['last_name'] = user.last_name
        token['is_superuser'] = user.is_superuser
        # token['user_type'] = user.user_type
        return token


User = get_user_model()

class BaseEmailCheckSerializer(serializers.Serializer):
    email = serializers.EmailField(required=True)

    def validate_email(self, value):
        return value.lower()

    def validate(self, attrs):
        email = attrs.get('email')
        
        user = User.objects.filter(email=email).first()
        if not user:
            raise serializers.ValidationError({
                "email": f"No account found for this email"
            })
            
        attrs['user'] = user
        return attrs

class EmailCheckSerializer(BaseEmailCheckSerializer):
    pass

==> houseteli_administrator-0.1.20-py3-none-any.whl: houseteli_administrator/h_auth/serializers.py <==
from dj_rest_auth.registration.serializers import RegisterSerializer
from rest_framework import serializers
from django.contrib.auth import get_user_model

User = get_user_model()

class CustomRegisterSerializer(RegisterSerializer):
    username = None
    email = serializers.EmailField(required=True)
    def custom_signup(self, request, user):
        user.email = self.data.get('email')
        user.save()


from rest_framework_simplejwt.serializers import TokenObtainPairSerializer
# from django.conf import settings
# from decouple import config
# account_type = config('ACCOUNTTYPE', default=None)
class CustomTokenObtainPairSerializer(TokenObtainPairSerializer):
    """
    Custom serializer to add extra claims to the JWT and only accept email and password.
    """
    email = serializers.EmailField()
    password = serializers.CharField(write_only=True)

    @classmethod
    def get_token(cls, user):
        token = super().get_token(user)
        
        # Add custom claims to the token
        token['email'] = user.email
        token['first_name'] = user.first_name
        token['last_name'] = user.last_name
        token['is_superuser'] = user.is_superuser
        return token

    def validate(self, attrs):
        # Ensure that only email and password are provided
        email = attrs.get('email')
        password = attrs.get('password')

        # Validate user using email and password
        user = self.authenticate_user(email, password)
        if not user:
            raise serializers.ValidationError('Invalid email or password.')

        # Return validated data with the user
        attrs['user'] = user
        return attrs

    def authenticate_user(self, email, password):
        """
        Custom method to authenticate a user using email and password.
        """
        from django.contrib.auth import authenticate
        
        # Authenticate the user by email (email is treated as username)
        user = authenticate(username=email, password=password)
        return user


User = get_user_model()

class BaseEmailCheckSerializer(serializers.Serializer):
    email = serializers.EmailField(required=True)

    def validate_email(self, value):
        return value.lower()

    def validate(self, attrs):
        email = attrs.get('email')
        
        user = User.objects.filter(email=email).first()
        if not user:
            raise serializers.ValidationError({
                "email": f"No account found for this email"
            })
            
        attrs['user'] = user
        return attrs

class EmailCheckSerializer(BaseEmailCheckSerializer):
    pass
